@@ -151,7 +151,7 @@
          "$TerminalBackground" "$Thursday" "$TimeSep" "$TimetIs64bit" "$Tm" "$Today" "$TodoFilter"
          "$Tomorrow" "$Tt" "$Tuesday" "$Tw" "$Ty" "$U" "$Ud" "$Um"
          "$UntimedFirst" "$Use256Colors" "$UseBGVTColors" "$UseTrueColors"
-         "$UseVTColors" "$Uw" "$Uy" "$Was" "$Wednesday")
+         "$UseVTColors" "$Uw" "$Uy" "$WarningLevel" "$Was" "$Wednesday")
    #'(lambda (a b) (> (length a) (length b)))))
 
 (defconst remind-time-words
@@ -166,12 +166,13 @@
 (defconst remind-builtin-functions
   (sort
    (list "_" "abs" "access" "adawn" "adusk" "ampm" "ansicolor" "args" "asc"
-         "baseyr" "catch" "catcherr" "char" "choose" "coerce" "columns" "const" "current" "date"
+         "baseyr" "catch" "catcherr" "char" "choose" "codepoint" "coerce" "columns" "const" "current" "date"
          "datepart" "datetime" "dawn" "day" "daysinmon" "defined" "dosubst"
          "dusk" "easterdate" "escape" "eval" "evaltrig" "filedate" "filedatetime"
-         "filedir" "filename" "getenv" "hebdate" "hebday" "hebmon" "hebyear"
+         "filedir" "filename" "getenv" "hebdate" "hebday" "hebmon" "hebyear" "hex"
          "hour" "htmlescape" "htmlstriptags" "iif" "index" "isany" "isconst" "isdst"
-         "isleap" "isomitted" "language" "localtoutc" "lower" "max" "min"
+         "isleap" "isomitted" "language" "localtoutc" "lower" "max"
+         "mbasc" "mbindex" "mbstrlen" "mbsubstr" "min"
          "minsfromutc" "minute" "mon" "monnum" "moondate" "moondatetime"
          "moonphase" "moonrise" "moonrisedir" "moonset" "moonsetdir" "moontime"
          "multitrig" "ndawn" "ndusk" "nonconst" "nonomitted" "now" "ord" "orthodoxeaster"
