@@ -690,7 +690,7 @@ sub draw_day
                 $cr->restore();
         }
 
-        $so_far += $h + 2 * $settings->{border_size};
+        $so_far += $h + $settings->{border_size};
         my $entry_height = 0;
         my $done = 0;
         foreach my $entry (@{$self->{entries}->[$day]}) {
@@ -819,7 +819,7 @@ sub draw_title
 
 =head2 get_rgb($color)
 
-Parses a 3- or 6-hex-digit color value and returs [red, green, blue].  If
+Parses a 3- or 6-hex-digit color value and returns [red, green, blue].  If
 color could not be parsed, returns undef
 
 =cut
