@@ -1870,7 +1870,9 @@ static void GenerateCalEntries(int col)
 
             default:
                 if (!SuppressImplicitRemWarnings) {
-                    Wprint("Unrecognized command; interpreting as REM");
+                    if (warning_level("05.00.03")) {
+                        Wprint(tr("Unrecognized command; interpreting as REM"));
+                    }
                     WarnedAboutImplicit = 1;
                 }
                 CreateParser(CurLine, &p);
@@ -2078,7 +2080,7 @@ static int DoCalRem(ParsePtr p, int col)
     }
 
     /* Adjust trigger date/time to time zone */
-    dse = AdjustTriggerForTimeZone(&trig, dse, &tim);
+    dse = AdjustTriggerForTimeZone(&trig, dse, &tim, 1);
 
     /* Add to global OMITs if so indicated */
     if (trig.addomit) {
@@ -2109,7 +2111,7 @@ static int DoCalRem(ParsePtr p, int col)
     }
 
     /* Save nonconst_expr flag */
-    nonconst_expr = p->nonconst_expr;
+    nonconst_expr = trig.nonconst_expr;
     /* Convert PS and PSF to PASSTHRU */
     if (trig.typ == PS_TYPE) {
         strcpy(trig.passthru, "PostScript");
