@@ -63,6 +63,7 @@ EXTERN  INIT(   int     MaxLateMinutes, 0);
 EXTERN  INIT(   int     NumTrustedUsers, 0);
 EXTERN  INIT(   char    const *MsgCommand, NULL);
 EXTERN  INIT(   char    const *QueuedMsgCommand, NULL);
+EXTERN  INIT(   char    const *WarningLevel, NULL);
 EXTERN  INIT(   int     ShowAllErrors, 0);
 EXTERN  INIT(   int     DebugFlag, 0);
 EXTERN  INIT(   int     DoCalendar, 0);
@@ -88,10 +89,10 @@ EXTERN  INIT(   int     DeltaOverride, 0);
 EXTERN  INIT(   int     RunDisabled, 0);
 EXTERN  INIT(   int     ExpressionEvaluationDisabled, 0);
 EXTERN  INIT(   int     ExpressionEvaluationTimeLimit, 0);
-EXTERN  INIT(   int     ExpressionNodesEvaluated, 0);
-EXTERN  INIT(   int     MaxExprNodesPerLine, 0);
-EXTERN  INIT(   int     ExpressionNodesEvaluatedThisLine, 0);
-EXTERN  INIT(   int     ExpressionNodeLimitPerLine, 0);
+EXTERN  INIT(   unsigned long  ExpressionNodesEvaluated, 0);
+EXTERN  INIT(   unsigned long  MaxExprNodesPerLine, 0);
+EXTERN  INIT(   unsigned long  ExpressionNodesEvaluatedThisLine, 0);
+EXTERN  INIT(   unsigned long  ExpressionNodeLimitPerLine, 10000000);
 EXTERN  INIT(   volatile sig_atomic_t ExpressionTimeLimitExceeded, 0);
 EXTERN  INIT(   int     IgnoreOnce, 0);
 EXTERN  INIT(   char const *OnceFile, NULL);
